/*
 * Main.c
 *
 * Created: 27.12.2012 12:54:58
 *  Author: Nuckey
 */ 
#include "Main.Init.h"
#include "Main.Text.h"


#include <util/delay.h>
#include <avr/sleep.h>
#include <stdlib.h>
#include <string.h>
#include <avr/eeprom.h>
#include <avr/pgmspace.h>
#include <avr/wdt.h>
#include <avr/interrupt.h>
#include <math.h>



//###################################################################################################
//# The voltage at a capacitor grows with  Uc = VCC * (1 - e**(-t/T))								#
//# The voltage 1.3V is reached at  t = -ln(3.7/5)*T  = 0.3011*T .									#
//# Time constant is  T = R * C ; also																#
//# C = T / R																						#
//# for the resistor 470 kOhm  is C = t / (0.3011 * 470000)											#
//# H_Fakt = 707/100 for a result in pF units.														#
//# Big Capacities (>50F) are measured with up to 500 load-pulses with the 680 Ohm resistor.		#
//# Each  of this load-puls has an length of 10ms. After every load-pulse the voltage of the		#
//# capacitor is measured. If the voltage is more than 300mV, the capacity is computed by			#
//# interpolating the corresponding values of the table RLtab and multiply that with the number		#
//# of load pulses (*10).																			#
//###################################################################################################

//###################################################################################################
//#									Widerstand 680 Ohm												#
//# 300   325   350   375   400   425   450   475   500   525   550   575   600   625   650   675	#
//# 700   725   750   775   800   825   850   875   900   925   950   975  1000  1025  1050  1075	#
//#  1100  1125  1150  1175  1200  1225  1250  1275  1300  1325  1350  1375  1400  mV				#
//###################################################################################################
const uint16_t RLtab[] MEM_TEXT = {22447,20665,19138,17815,16657,15635,14727,13914,13182,12520,11918,11369,10865,10401, 9973, 9577, 9209, 8866, 8546, 8247, 7966, 7702, 7454, 7220, 6999, 6789, 6591, 6403, 6224, 6054, 5892, 5738, 5590, 5449, 5314, 5185, 5061, 4942, 4828, 4718, 4613, 4511, 4413, 4319, 4228};

#if FLASHEND > 0x1fff
const uint8_t LogTab[] MEM2_TEXT = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 11, 12, 13, 14, 15, 16, 17, 19, 20, 21, 22, 24, 25, 26, 27, 29, 30, 31, 33, 34, 36, 37, 39, 40, 42, 43, 45, 46, 48, 49, 51, 53, 54, 56, 58, 60, 62, 63, 65, 67, 69, 71, 73, 76, 78, 80, 82, 84, 87, 89, 92, 94, 97, 99, 102, 105, 108, 111, 114, 117, 120, 124, 127, 131, 135, 139, 143, 147, 151, 156, 161, 166, 171, 177, 183, 190, 197, 204, 212, 221, 230, 241 };
#endif

//###################################################################################
//#					resistor  470000 Ohm											#
//# 1000 1050 1100 1150 1200 1250 1300 1350 1400  mV								#
//###################################################################################
#ifdef AUTO_RH
 const uint16_t RHtab[] MEM_TEXT = { 954, 903, 856, 814, 775, 740, 707, 676, 648};
#endif



#ifdef AUTO_CAL
const uint16_t R680pl EEMEM = R_L_VAL+PIN_RP;	// total resistor to VCC
const uint16_t R680mi EEMEM = R_L_VAL+PIN_RM;	// total resistor to GND
const int8_t RefDiff EEMEM = REF_R_KORR;	// correction of internal Reference Voltage

//  const uint16_t cap_null EEMEM = C_NULL;	// Zero offset of capacity measurement
const int16_t ref_offset EEMEM = REF_C_KORR;	// default correction of internal reference voltage for capacity measurement
// LoPin:HiPin                        2:1    3:1    1:2                    :     3:2                   1:3    2:3
const uint8_t c_zero_tab[] EEMEM = { C_NULL,C_NULL,C_NULL+TP2_CAP_OFFSET,C_NULL,C_NULL+TP2_CAP_OFFSET,C_NULL,C_NULL }; //table of zero offsets
#endif

const uint8_t EE_ESR_ZERO EEMEM = ESR_ZERO;	// zero offset of ESR measurement



//End of EEPROM-Strings
// Multiplier for capacity measurement with R_H (470KOhm)
unsigned int RHmultip=DEFAULT_RH_FAKT;

const unsigned char PinRLtab[] MEM_TEXT = { (1<<(TP1*2)),(1<<(TP2*2)),(1<<(TP3*2))};	// Table of commands to switch the  R-L resistors Pin 0,1,2
const unsigned char PinADCtab[] MEM_TEXT = { (1<<TP1),(1<<TP2),(1<<TP3)};	// Table of commands to switch the ADC-Pins 0,1,2


